@@ -1,6 +1,9 @@
 from django import template
+from django.utils.encoding import smart_str, force_unicode
 import markdown, textile
 from docutils.core import publish_parts
+from textwrap import dedent
+from django.conf import settings
 
 register = template.Library()
 
@@ -18,7 +21,7 @@ class MarkdownNode(template.Node):
 
     def render(self, context):
         output = self.nodelist.render(context)
-        return markdown.markdown(output)
+        return markdown.markdown(dedent(output))
 
 
 @register.tag(name="textile")
@@ -34,7 +37,7 @@ class TextileNode(template.Node):
 
     def render(self, context):
         output = self.nodelist.render(context)
-        return textile.textile(output)
+        return textile.textile(dedent(output))
 
 
 @register.tag(name="restructuredtext")
@@ -50,5 +53,6 @@ class RestructuredtextNode(template.Node):
 
     def render(self, context):
         output = self.nodelist.render(context)
-        parts = publish_parts(source=output)
-        return parts["fragment"]
+        docutils_settings = getattr(settings, "RESTRUCTUREDTEXT_FILTER_SETTINGS", {})
+        parts = publish_parts(source=smart_str(dedent(output)), writer_name="html4css1", settings_overrides=docutils_settings)
+        return parts['whole']
